@@ -73,7 +73,10 @@ module RMail
 
     class Field                 # :nodoc:
       # fixme, document methadology for this (RFC2822)
-      EXTRACT_FIELD_NAME_RE = /\A([^\x00-\x1f\x7f-\xff :]+):\s*/no
+
+      # accoring to RFC2822 the header field name can consist of any
+      # ASCII char between and including 33 and 126.
+      EXTRACT_FIELD_NAME_RE = /\A(^\w[-\w]+):\s*/o
 
       class << self
         def parse(field)
@@ -533,8 +536,9 @@ module RMail
     # executed and its return value is returned.  If no block is passed,
     # the value of the +default+ argument is returned.
     def content_type(default = nil)
-      if value = self['content-type']
-	value.strip.split(/\s*;\s*/)[0].downcase
+      content_type = self['content-type']
+      if content_type && content_type.length > 0
+	content_type.strip.split(/\s*;\s*/)[0].downcase
       else
 	if block_given?
           yield
