@@ -781,6 +781,10 @@ EOF
     h.delete('content-type')
     h['content-type'] = ' foo/html   ; charset=ISO-8859-1'
     assert_equal("foo/html", h.content_type)
+
+    h = RMail::Header.new
+    h['content-type'] = ''
+    assert_equal(nil, h.content_type)
   end
 
   def test_media_type
@@ -1021,18 +1025,7 @@ EOF
     begin
       h = RMail::Header.new
       # This one is bogus and can't even be parsed.
-      h.add_raw("Date: 21/01/2002 09:29:33 Pacific Daylight Time")
-      t = assert_nothing_raised {
-        h.date
-      }
-      assert_nil(t)
-    end
-
-    begin
-      h = RMail::Header.new
-      # This time is out of the range that can be represented by a
-      # Time object.
-      h.add_raw("Date: Sun, 14 Jun 2065 05:51:55 +0200")
+      h.add_raw("Date: A long time ago")
       t = assert_nothing_raised {
         h.date
       }
@@ -1227,4 +1220,14 @@ EOF
     assert_equal(0, h.recipients.length)
   end
 
+  def test_invalid_encoding_utf8
+    _, value = RMail::Header::Field.parse('Subject: abgeändertes Angebot')
+    assert_equal 'abgeändertes Angebot', value
+  end
+
+  def test_invalid_encoding_iso_8859_1
+    _, value = RMail::Header::Field.parse('Subject: abgeändertes Angebot'.encode(Encoding::ISO_8859_1))
+    assert_equal 'abgeändertes Angebot'.encode(Encoding::ISO_8859_1), value
+  end
+
 end
